@@ -1,9 +1,9 @@
 #!/bin/sh
-export PATH='/usr/obj/ports/hs-HDBC-postgresql-2.3.2.4/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/X11R6/bin'
+export PATH='/usr/obj/ports/hs-HDBC-postgresql-2.3.2.5/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/X11R6/bin'
 echo 'name: HDBC-postgresql
-version: 2.3.2.4
-id: HDBC-postgresql-2.3.2.4-b637a85ba1350feb5dc7bf4fb66eac0e
-key: HDBCp_8U3tZlttKMl3tT06Sq1dHe
+version: 2.3.2.5
+id: HDBC-postgresql-2.3.2.5-b156cd58d04ae0ae1ba4343b1a1577ac
+key: HDBCp_Lnzuk56AQgSERSgUalPem0
 license: BSD3
 copyright: Copyright (c) 2005-2011 John Goerzen
 maintainer: Nicolas Wu <nicolas.wu@gmail.com>
@@ -24,24 +24,24 @@ hidden-modules: Database.HDBC.PostgreSQL.Connection
                 Database.HDBC.PostgreSQL.PTypeConv
                 Database.HDBC.PostgreSQL.ErrorCodes
 trusted: False
-import-dirs: /usr/local/lib/ghc/HDBC-postgresql-2.3.2.4
-library-dirs: /usr/local/lib/ghc/HDBC-postgresql-2.3.2.4
+import-dirs: /usr/local/lib/ghc/HDBC-postgresql-2.3.2.5
+library-dirs: /usr/local/lib/ghc/HDBC-postgresql-2.3.2.5
               /usr/local/lib
-data-dir: /usr/local/share/hs-HDBC-postgresql-2.3.2.4
-hs-libraries: HSHDBC-postgresql-2.3.2.4-8U3tZlttKMl3tT06Sq1dHe
+data-dir: /usr/local/share/hs-HDBC-postgresql-2.3.2.5
+hs-libraries: HSHDBC-postgresql-2.3.2.5-Lnzuk56AQgSERSgUalPem0
 extra-libraries:
     pq crypto ssl
 include-dirs: /usr/local/include/postgresql
 depends:
-    HDBC-2.4.0.1-5ab74fa29594c0cd65fa0a34e04335f8
-    base-4.8.2.0-8dd7859ce039df9f3d3f4ff9dbf4bb93
-    bytestring-0.10.6.0-8a126a308e25adafa4b7221965acccd5
+    HDBC-2.4.0.2-ec2a5ade5f1a8868f0d51b053ad31934
+    base-4.8.2.0-998280bdde83e17200455ba43ed33188
+    bytestring-0.10.6.0-fd9ecdc10518a92e9e756e845ae35989
     convertible-1.1.1.0-9094a83e9ce58ef3a67f72838d63635d
     mtl-2.2.1-3af90341e75ee52dfc4e3143b4e5d219
     old-time-1.1.0.3-4494378134a1c0eadea2f9ea5411834e
     parsec-3.1.9-d2c139e64f1c778850f609850ceafa14
     time-1.5.0.1-1b9a502bb07a3e6f4d6935fbf9db7181
     utf8-string-1.0.1.1-09f6924ad5da4f093413455bda66bd2c
-haddock-interfaces: /usr/local/share/doc/hs-HDBC-postgresql-2.3.2.4/html/HDBC-postgresql.haddock
-haddock-html: /usr/local/share/doc/hs-HDBC-postgresql-2.3.2.4/html
+haddock-interfaces: /usr/local/share/doc/hs-HDBC-postgresql-2.3.2.5/html/HDBC-postgresql.haddock
+haddock-html: /usr/local/share/doc/hs-HDBC-postgresql-2.3.2.5/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
